SystemOrganization addCategory: #'Seaside-Tests-Slime'!

TestCase subclass: #WASlimeTest
	instanceVariableNames: 'model environment'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Slime'!

!WASlimeTest methodsFor: 'accessing-code' stamp: 'lr 1/25/2010 22:07'!
canParse: aString
	RBParser
		parseMethod: aString
		onError: [ :err :pos | ^ false ].
	^ true! !

!WASlimeTest methodsFor: 'accessing' stamp: 'lr 1/25/2010 22:07'!
category
	^ self class category , '-Data'! !

!WASlimeTest methodsFor: 'accessing-code' stamp: 'lr 1/25/2010 22:07'!
compile: aString in: aClass
	^ aClass compile: aString classified: #(accessing)! !

!WASlimeTest methodsFor: 'accessing-code' stamp: 'lr 1/24/2010 18:19'!
defineClass: aClassSymbol superclass: aSuperSymbol
	| class |
	model defineClass: aSuperSymbol , ' subclass: #' , aClassSymbol , '
		instanceVariableNames: '''' 
		classVariableNames: ''''
		poolDictionaries: ''''
		category: ''' , self category , ''''.
	class := model classNamed: aClassSymbol.
	environment 
		addClass: class;
		addClass: class theMetaClass.
	^ class! !

!WASlimeTest methodsFor: 'accessing' stamp: 'lr 1/24/2010 18:23'!
rules
	^ OrderedCollection new
		addAll: WASlimeBlockLintRule allSubclasses;
		addAll: WASlimeParseTreeLintRule allSubclasses;
		addAll: WASlimeTransformationRule allSubclasses;
		yourself! !

!WASlimeTest methodsFor: 'running-checks' stamp: 'lr 1/25/2010 22:07'!
run: aClass do: aBlock
	| rules rule composite undo |
	rules := self rules
		collect: [ :each | each new ].
	rule := rules
		detect: [ :each | each isKindOf: aClass ]
		ifNone: [ self error: aClass name , ' is not a slime rule' ].
	self
		assert: (rule name isString and: [ rule name notEmpty ])
		description: aClass name , ' has no name'.
	self
		assert: (rule rationale isString and: [ rule rationale notEmpty and: [ rule rationale endsWith: '.' ] ])
		description: aClass name , ' has no rationale'.
	composite := RBCompositeLintRule rules: rules name: 'Slime'.
	undo := model changes execute.
	[	SmalllintChecker runRule: composite onEnvironment: environment.
		rules do: [ :each |
			self 
				assert: (rule = each or: [ each result isEmpty and: [ each changes isEmpty ] ])
				description: each name , ' should not report errors' ].
		aBlock value: rule value: rules ]
			ensure: [ undo execute ].
	^ rule! !

!WASlimeTest methodsFor: 'running' stamp: 'lr 1/24/2010 18:15'!
runCase
	SystemChangeNotifier uniqueInstance
		doSilently: [ super runCase ]! !

!WASlimeTest methodsFor: 'running-checks' stamp: 'lr 1/25/2010 22:07'!
runRule: aClass selectors: aCollection
	self run: aClass do: [ :rule :rules |
		rule result classesAndSelectorsDo: [ :class :selector |
			self
				assert: (aCollection includes: selector)
				description: selector printString , ' should not be reported' ].
		aCollection do: [ :selector |
			self
				assert: (rule result classes
					anySatisfy: [ :class | rule result includesSelector: selector in: class ])
				description: selector printString , ' should be reported' ] ]! !

!WASlimeTest methodsFor: 'running-checks' stamp: 'lr 1/25/2010 22:07'!
runTransformation: aClass changes: aCollection
	| expected |
	expected := aCollection 
		collect: [ :each | RBParser parseMethod: each ].
	self run: aClass do: [ :rule :rules |
		rule changes do: [ :change |
			self
				assert: (expected anySatisfy: [ :parseTree | change parseTree = parseTree ])
				description: change selector , ' should not be transformed' ].
		expected do: [ :parseTree |
			self
				assert: (rule changes anySatisfy: [ :change | change parseTree = parseTree ])
				description: parseTree selector , ' should be transformed' ] ]! !

!WASlimeTest methodsFor: 'running' stamp: 'lr 1/24/2010 18:15'!
setUp
	super setUp.
	model := RBNamespace new.
	environment := ClassEnvironment new! !

!WASlimeTest methodsFor: 'running' stamp: 'lr 1/25/2010 22:07'!
tearDown
	super tearDown.
	Smalltalk organization
		removeCategory: self category! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiBooleansRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'and 1 and: [ 2 ] and: [ 3 ] and: [ 4 ]' in: class.
	self compile: 'or 1 or: [ 2 ] or: [ 3 ] or: [ 4 ]' in: class.
	self 
		runTransformation: WAAnsiBooleansRule
		changes: #(
			'and 1 and: [ 2 and: [ 3 and: [ 4 ] ] ]'
			'or 1 or: [ 2 or: [ 3 or: [ 4 ] ] ]' )! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiCharacterRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'character Character value: 123' in: class.
	self compile: 'characterRange $a to: $c' in: class.
	self 
		runTransformation: WAAnsiCharactersRule
		changes: #('character Character codePoint: 123' 'characterRange ''abc''')! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiCollectionsRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'withIndexDo #() withIndexDo: [ :each :index | each + index ]' in: class.
	self compile: 'doWithIndex #() doWithIndex: [ :each :index | each + index ]' in: class.
	self compile: 'collectThenDo #() collect: [ :a | a ] thenDo: [ :b | b ]' in: class.
	self compile: 'collectThenSelect #() collect: [ :a | a ] thenSelect: [ :b | true ]' in: class.
	self compile: 'detectSum #(1 2) detectSum: [ :each | each]' in: class.
	self compile: 'detectSumMultiline #(1 2) detectSum: [ :each | #foo copy. each ]' in: class.
	self compile: 'pairsDo #(1 2 3 4) pairsDo: [ :a :b | b ]' in: class.
	self compile: 'rejectThenDo #() reject: [ :a | true ] thenDo: [ :b | b ]' in: class.
	self compile: 'selectThenCollect #() select: [ :a | true ] thenCollect: [ :b | b ]' in: class.
	self compile: 'selectThenDo #() select: [ :a | true ] thenDo: [ :b | b ]' in: class.
	self compile: 'valuesDo #() valuesDo: [ :a | a ]' in: class.
	self 
		runTransformation: WAAnsiCollectionsRule
		changes: #( 
			'withIndexDo #() keysAndValuesDo: [ :index :each | each + index ]'
			'doWithIndex #() keysAndValuesDo: [ :index :each | each + index ]'
			'collectThenDo (#() collect: [ :a | a ]) do: [ :b | b ]'
			'selectThenDo (#() select: [ :a | true ]) do: [ :b | b ]'
			'rejectThenDo (#() reject: [ :a | true ]) do: [ :b | b ]'
			'selectThenCollect (#() select: [ :a | true ]) collect: [ :b | b ]'
			'pairsDo 1 to: #(1 2 3 4) size by: 2 do: [ :index | |a b| a := #(1 2 3 4) at: index. b := #(1 2 3 4) at: index + 1. b ]'
			'collectThenSelect (#() collect: [ :a | a ]) select: [ :b | true ]'
			'detectSum #(1 2) inject: 0 into: [ :sum :each | sum + each ]'
			'detectSumMultiline #(1 2) inject: 0 into: [ :sum :each | #foo copy. sum + each ]'
			'valuesDo #() do: [ :a | a ]' )! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiConditionalsRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'ifNotNil 1 ifNotNil: [ | a | self or. self and ]' in: class.
	self compile: 'ifNotNilDo 1 ifNotNilDo: [ :a | ^ a ]' in: class.
	self 
		runTransformation: WAAnsiConditionalsRule
		changes: #( 
			'ifNotNil 1 ifNotNil: [ :arg | | a | self or. self and ]'
			'ifNotNilDo 1 ifNotNil: [ :a | ^ a ]' )! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiConvertorRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'convertInteger ''1'' asInteger' in: class.
	self compile: 'convertString 2 asString' in: class.
	self 
		runTransformation: WAAnsiConvertorRule
		changes: #( 
			'convertInteger ''1'' greaseInteger'
			'convertString 2 greaseString' )! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiExceptionsRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'exception1 [ self or ] on: Error do: [ self or ]' in: class.
	self compile: 'exception2 [ self or ] on: Error do: [ self or. self or ]' in: class.
	self compile: 'exception3 [ self or ] on: Error do: [ | a | a := 0 ]' in: class.
	self 
		runTransformation: WAAnsiExceptionsRule
		changes: #( 
			'exception1 [ self or ] on: Error do: [ :err | self or ]'
			'exception2 [ self or ] on: Error do: [ :err | self or. self or ]'
			'exception3 [ self or ] on: Error do: [ :err | | a | a := 0 ]' )! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiStreamsRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'writeStream ^ '''' writeStream' in: class.
	self compile: 'writeCr | stream | stream := WriteStream on: ''''. stream cr. stream nextPut: Character cr' in: class.
	self compile: 'writeLf | stream | stream := WriteStream on: ''''. stream lf. stream nextPut: Character lf' in: class.
	self 
		runTransformation: WAAnsiStreamsRule
		changes: #( 
			'writeStream ^ WriteStream on: '''''
			'writeCr | stream | stream := WriteStream on: ''''. stream nextPut: Character cr. stream nextPut: Character cr'
			'writeLf | stream | stream := WriteStream on: ''''. stream nextPut: Character lf. stream nextPut: Character lf')! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testAnsiStringsRule
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'stringCr String cr, (String with: Character cr)' in: class.
	self compile: 'stringTab String tab, (String with: Character tab)' in: class.
	self compile: 'stringLf String lf, (String with: Character lf)' in: class.
	self compile: 'stringCrLf String crlf, (String with: Character cr with: Character lf)' in: class.
	self compile: 'stringSpace String space, (String with: Character space)' in: class.
	self compile: 'findTokens ''123'' findTokens: '',''' in: class.
	self compile: 'findTokensCharacter ''123'' findTokens: $,' in: class.
	self 
		runTransformation: WAAnsiStringsRule
		changes: #( 
			'stringCr (String with: Character cr), (String with: Character cr)'
			'stringTab (String with: Character tab), (String with: Character tab)'
			'stringLf (String with: Character lf), (String with: Character lf)'
			'stringCrLf (String with: Character cr with: Character lf), (String with: Character cr with: Character lf)'
			'stringSpace (String with: Character space), (String with: Character space)'
			'findTokens ''123'' subStrings: '','''
			'findTokensCharacter ''123'' subStrings: '',''' )! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testBasicNewInitializeMissing
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #Object.
	self compile:  'initialize' in: class.
	self
		runRule: WABasicNewInitializeMissingRule
		selectors: #(initialize)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testCallSuperImplementation
	| object painter |
	object := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'postCopy self postCopy' in: object. 
	painter := self
		defineClass: #WASlimeMockComponent
		superclass: #WAPainter.
	self compile:  'updateRoot: aHtmlRoot self updateUrl: aHtmlRoot' in: painter.
	self
		runRule: WACallSuperImplementationRule
		selectors: #(postCopy updateRoot:)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testChangesStateWhileRendering
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class addInstanceVariable: 'foo'.
	self compile: 'renderContentOn: html html div: [ foo := nil ]' in: class.
	self 
		runRule: WAChangesStateWhileRenderingRule
		selectors: #(renderContentOn:)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testDeprecatedApiProtocol
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'deprecated1 self greaseDeprecatedApi: ''WASlimeMockObject>>#deprecated1'' details: ''Something.''' in: class.
	self compile: 'deprecated2 self greaseDeprecatedApi: ''WASlimeMockObject>>#deprecated'' details: ''Something.''' in: class.
	self compile: 'deprecated3 self greaseDeprecatedApi: ''WASlimeMock>>#deprecated3'' details: ''Something.''' in: class.
	self 
		runRule: WADeprecatedApiProtocolRule
		selectors: #(deprecated2 deprecated3)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testDoNotUseWhileRendering
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self compile: 'renderContentOn: html html div: [ self call: nil ]' in: class.
	self 
		runRule: WADoNotUseWhileRenderingRule
		selectors: #(renderContentOn:)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testDoNotUseWithinCallback
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self compile: 'renderContentOn: html
		html anchor
			callback: [ html document addLoadScript: nil ];
			with: 123' in: class.
	self 
		runRule: WADoNotUseWithinCallbackRule
		selectors: #(renderContentOn:)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testEmptyStatements
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'emptyStatement1. self and' in: class.
	self compile: 'emptyStatement2 self and..' in: class.
	self compile: 'emptyStatement3 self and."foo".' in: class.
	self compile: 'emptyStatement4 self and."foo".self and' in: class.
	self 
		runRule: WAEmptyStatementsRule
		selectors: #(emptyStatement1 emptyStatement2 emptyStatement3 emptyStatement4)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testExtractCallbackCodeToMethod
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderInvalidOn: html
			html anchor 
				callback: [ self foo. self bar ];
				with: 1'
		classified: #(rendering).
	class
		compile: 'renderValidOn: html
			html anchor 
				callback: [ self foo ];
				with: 1'
		classified: #(rendering).
	self 
		runRule: WAExtractCallbackCodeToMethodRule
		selectors: #(renderInvalidOn:)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testFixCallbackTempsMissing
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self
		compile: 'callbackTemps | r | r := OrderedCollection new. (1 to: 10) do: [ :e | r add: [ e ] ]' 
		in: class.
	self 
		runRule: WAFixCallbackTempsMissingRule
		selectors: #(callbackTemps)! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testHandleRequestRule
	| class |
	class := self
		defineClass: #WASlimeMockHandler
		superclass: #WARequestHandler.
	self compile: 'handleRequest: aRequest aRequest notFound' in: class.
	self 
		runTransformation: WAHandleRequestRule
		changes: #('handleFiltered: aRequestContext aRequestContext request notFound')! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testInstantiatesComponentWhileRendering
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self compile: 'renderContentOn: html html div: WAComponentStub new' in: class.
	self 
		runRule: WAInstantiatesComponentWhileRenderingRule
		selectors: #(renderContentOn:)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testInvalidObjectInitialization
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile:  'initializeFoo: aNumber' in: class.
	self 
		runRule: WAInvalidObjectInitializationRule
		selectors: #(initializeFoo:)! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 22:07'!
testObjectIn
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'objectIn1 1 in: [ :val | val factorial ]' in: class.
	self compile: 'objectIn2 2 in: [ :val | | temps | val factorial ]' in: class.
	self compile: 'objectIn3 2 in: [ ''not this'' ]' in: class.
	self 
		runTransformation: WAObjectInRule
		changes: #(
			'objectIn1 [ :val | val factorial ] value: 1'
			'objectIn2 [ :val | | temps | val factorial ] value: 2')! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testSendsRenderContentOn
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'invalid self renderContentOn: nil'
		classified: #(rendering).
	self 
		runRule: WASendsRenderContentOnRule
		selectors: #(invalid)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testSequencedAsynchronousCalls
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContent1On: html
			html div
				onClick: (html jQuery ajax callback: [  ]) , (html jQuery ajax serializeForm);
				with: ''Click me'''
		classified: #(rendering).
	class
		compile: 'renderContent2On: html
			html div
				onClick: (html jQuery ajax serializeForm; callback: [  ]) , (html jQuery effect bounce);
				with: ''Click me'''
		classified: #(rendering).
	self 
		runRule: WASequencedAsynchronousCallsRule
		selectors: #(renderContent1On: renderContent2On:)! !

!WASlimeTest methodsFor: 'testing-transform' stamp: 'lr 1/25/2010 21:59'!
testSessionExpiredRule
	| class |
	class := self
		defineClass: #WASlimeMockSession
		superclass: #WASession.
	self compile: 'expired self cleanup' in: class.
	self 
		runTransformation: WASessionExpiredRule
		changes: #('unregistered self cleanup')! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testUnnecessaryBlockPassedToBrush
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContent01On: html html div: [ ]'
		classified: #(rendering).
	class
		compile: 'renderContent02On: html html div: [ html text: 2 ]'
		classified: #(rendering).
	class
		compile: 'renderContent03On: html html div: [ html render: 3 ]'
		classified: #(rendering).
	class
		compile: 'renderContent04On: html html div class: #foo; with: [ ]'
		classified: #(rendering).
	class
		compile: 'renderContent05On: html html div class: #foo; with: [ html text: 5 ]'
		classified: #(rendering).
	class
		compile: 'renderContent06On: html html div class: #foo; with: [ html render: 6 ]'
		classified: #(rendering).
	self
		runRule: WAUnnecessaryBlockPassedToBrushRule
		selectors: #(renderContent01On: renderContent02On: renderContent03On: renderContent04On: renderContent05On: renderContent06On:)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testUnnecessaryWithSentToBrush
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContentOn: html html div with: 123'
		classified: #(rendering).
	self
		runRule: WAUnnecessaryWithSentToBrushRule
		selectors: #(renderContentOn:)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testUsesCurlyBraceArrays
	| class |
	(self canParse: 'foo { self foo. self bar }')
		ifFalse: [ ^ self ].
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	class
		compile: 'invalid
			^ { self foo. self bar }'
		classified: #(accessing).
	class
		compile: 'valid
			^ Array new'
		classified: #(accessing).
	self 
		runRule: WAUsesCurlyBraceArraysRule
		selectors: #(invalid)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testUsesLiteralByteArrays
	| class |
	(self canParse: 'foo #[ 1 2 3 ]')
		ifFalse: [ ^ self ].
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	class
		compile: 'invalid
			^ #[ 1 2 3 ]'
		classified: #(accessing).
	class
		compile: 'valid
			^ ByteArray with: 1 with: 2 with: 3'
		classified: #(accessing).
	self 
		runRule: WAUsesLiteralByteArraysRule
		selectors: #(invalid)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testUsesMethodAnnotations
	| class |
	(self canParse: 'foo <foo: 123>')
		ifFalse: [ ^ self ].
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'invalid <foo: 123>' in: class.
	self compile: 'valid' in: class.
	self 
		runRule: WAUsesMethodAnnotationsRule
		selectors: #(invalid)! !

!WASlimeTest methodsFor: 'testing-block' stamp: 'lr 1/25/2010 22:07'!
testUsesNotPortableClass
	| class |
	class := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'invalid ^ Semaphore new' in: class.
	self compile: 'valid ^ WAObject new' in: class.
	self 
		runRule: WAUsesNotPortableClassRule
		selectors: #(invalid)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testUsesWrongRenderer
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContentOn: html
			html updater callback: [ :r | html div ]'
		classified: #(rendering).
	self 
		runRule: WAUsesWrongRendererRule
		selectors: #(renderContentOn:)! !

!WASlimeTest methodsFor: 'testing-parsetree' stamp: 'lr 1/25/2010 22:07'!
testWithHasToBeLastMessageInCascade
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContent01On: html
			html div
				with: ''foo'';
				class: ''bar''.'
		classified: #(rendering).
	class
		compile: 'renderContent02On: html
			html div
				id: ''zork'';
				with: ''foo'';
				class: ''bar''.'
		classified: #(rendering).
	self 
		runRule: WAWithHasToBeLastMessageInCascadeRule
		selectors: #(renderContent01On: renderContent02On:)! !

!GRPackage class methodsFor: '*seaside-tests-slime' stamp: 'jf 1/11/2009 14:12'!
seasideTestsSlime
	^ self new
		name: 'Seaside-Tests-Slime';
		description: 'Unit tests for the package Seaside-Slime.';
		addDependency: 'Seaside-Slime';
		addDependency: 'Seaside-Tests-Component';
		yourself! !
